@@ -1,5 +1,6 @@
 import copy
 
+
 def nestedShit(pureScript, fill, prevPageIndex, prevContentIndex, prevSceneIndex):
     while prevPageIndex < len(pureScript):
         page = pureScript[prevPageIndex]
@@ -24,7 +25,6 @@ def nestedShit(pureScript, fill, prevPageIndex, prevContentIndex, prevSceneIndex
 
 def fillTimestamps(pureScript):
     startTimestamp = [0, 0]
-    index = 0
     countInBetween = 0
 
     prevPageIndex = 0
@@ -35,42 +35,47 @@ def fillTimestamps(pureScript):
     while pageIndex < len(pureScript):
         page = pureScript[pageIndex]
         contentIndex = 0
+        if "type" in page and page["type"] == "FIRST_PAGES":
+            pageIndex += 1
+            continue
         while contentIndex < len(page["content"]):
             sceneIndex = 0
             content = page["content"][contentIndex]
-            if "scene_info" in content:
-                while sceneIndex < len(content["scene"]):
-                    scene = content["scene"][sceneIndex]
+            while sceneIndex < len(content["scene"]):
+                scene = content["scene"][sceneIndex]
+                # stuff to do
+                if "timestamp" in scene:
+                    fill = scene["timestamp"][0] - startTimestamp[1]
+                    fill = fill / countInBetween if countInBetween > 0 else 0
 
-                    # stuff to do
-                    if "timestamp" in scene:
-                        fill = scene["timestamp"][0] - startTimestamp[1]
-                        fill = fill / countInBetween if countInBetween > 0 else 0
+                    scene["duration"] = scene["timestamp"][1] - scene["timestamp"][0]
 
-                        scene["duration"] = (
-                            scene["timestamp"][1] - scene["timestamp"][0]
+                    if countInBetween > 0:
+                        pureScript = nestedShit(
+                            pureScript,
+                            fill,
+                            prevPageIndex,
+                            prevContentIndex,
+                            prevSceneIndex,
                         )
 
-                        if countInBetween > 0:
-                            pureScript = nestedShit(
-                                pureScript,
-                                fill,
-                                prevPageIndex,
-                                prevContentIndex,
-                                prevSceneIndex,
-                            )
-
-                        startTimestamp = copy.copy(scene["timestamp"])
+                    firstTimestamp = (
+                        True
+                        if startTimestamp[0] == 0 and startTimestamp[1] == 0
+                        else False
+                    )
+                    startTimestamp = copy.copy(scene["timestamp"])
+                    if firstTimestamp:
                         del scene["timestamp"]
 
-                        countInBetween = 0
-                        prevPageIndex = pageIndex
-                        prevContentIndex = contentIndex
-                        prevSceneIndex = sceneIndex + 1
-                    else:
-                        countInBetween += 1
+                    countInBetween = 0
+                    prevPageIndex = pageIndex
+                    prevContentIndex = contentIndex
+                    prevSceneIndex = sceneIndex + 1
+                else:
+                    countInBetween += 1
 
-                    sceneIndex += 1
+                sceneIndex += 1
             contentIndex += 1
         pageIndex += 1
     return pureScript
