@@ -1,12 +1,12 @@
 import copy
 
 
-def removeStopwordsSubs(nlp, subtitle):
-    subtitleWithoutStopWords = []
+def extractLemmaSubs(nlp, subtitle):
+    subsLemma = []
     for line in subtitle:
         doc = nlp(line["content"])
         tokens = [token.lemma_ for token in doc if not token.is_punct]
-        subtitleWithoutStopWords.append(
+        subsLemma.append(
             {
                 "lemma": tokens,
                 "content": line["content"],
@@ -15,11 +15,11 @@ def removeStopwordsSubs(nlp, subtitle):
             }
         )
 
-    return subtitleWithoutStopWords
+    return subsLemma
 
 
-def removeStopwordsScript(nlp, script):
-    def removeStopwordsAndReturnLemma(dialogue):
+def extractLemmaScript(nlp, script):
+    def returnLemma(dialogue):
         screenplayWithoutStopWords = []
 
         # extract lemma from dialogue
@@ -28,10 +28,8 @@ def removeStopwordsScript(nlp, script):
         screenplayWithoutStopWords += tokens
         return screenplayWithoutStopWords
 
-    scriptWithoutStopWords = []
+    scriptLemma = []
     for content in script:
-        scriptWithoutStopWords.append(copy.copy(content))
-        scriptWithoutStopWords[-1]["lemma"] = removeStopwordsAndReturnLemma(
-            content["dialogue"]
-        )
-    return scriptWithoutStopWords
+        scriptLemma.append(copy.copy(content))
+        scriptLemma[-1]["lemma"] = returnLemma(content["dialogue"])
+    return scriptLemma
